package javax.xml.stream;

import java.io.InputStream;
import java.security.PrivilegedActionException;
import java.io.FileNotFoundException;
import java.security.PrivilegedExceptionAction;
import java.io.FileInputStream;
import java.io.File;
import java.security.AccessController;
import java.security.PrivilegedAction;

class SecuritySupport
{
    SecuritySupport() {
    }
    
    ClassLoader getContextClassLoader() throws SecurityException {
        return (ClassLoader)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                ClassLoader cl = null;
                cl = Thread.currentThread().getContextClassLoader();
                if (cl == null) {
                    cl = ClassLoader.getSystemClassLoader();
                    return cl;
                }
                return cl;
            }
        });
    }
    
    String getSystemProperty(final String propName) {
        return (String)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                return System.getProperty(propName);
            }
        });
    }
    
    FileInputStream getFileInputStream(final File file) throws FileNotFoundException {
        try {
            return (FileInputStream)AccessController.doPrivileged(new PrivilegedExceptionAction() {
                @Override
                public Object run() throws FileNotFoundException {
                    return new FileInputStream(file);
                }
            });
        }
        catch (PrivilegedActionException e) {
            throw (FileNotFoundException)e.getException();
        }
    }
    
    InputStream getResourceAsStream(final ClassLoader cl, final String name) {
        return (InputStream)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                if (cl == null) {
                    InputStream ris = Object.class.getResourceAsStream(name);
                    return ris;
                }
                InputStream ris = cl.getResourceAsStream(name);
                return ris;
            }
        });
    }
    
    boolean doesFileExist(final File f) {
        return (boolean)AccessController.doPrivileged(new PrivilegedAction() {
            @Override
            public Object run() {
                return new Boolean(f.exists());
            }
        });
    }
}
